@@ -16,8 +16,15 @@ class IcingaHelper(object):
     def set_ansible_inventory(inventory):
         IcingaHelper.inventory = inventory
 
+    # set by ../conftest.py
+    @staticmethod
+    def set_ssh_identity_file(ssh_identity_file):
+        IcingaHelper.ssh_identity_file = ssh_identity_file
+
     def get_auth(self):
-        host = testinfra.get_host('ansible://icinga-host', ansible_inventory=self.inventory)
+        host = testinfra.get_host('ansible://icinga-host',
+                                  ssh_identity_file=self.ssh_identity_file,
+                                  ansible_inventory=self.inventory)
         with host.sudo():
             f = host.file("/etc/icinga2/conf.d/api-users.conf")
             return (
@@ -27,11 +34,13 @@ class IcingaHelper(object):
 
     def get_address(self):
         if get_driver() == 'openstack':
-            vars_dir = '../../inventory/group_vars/all'
+            vars_dir = f'{self.inventory}/group_vars/all'
             return 'icinga.' + yaml.load(
                 open(vars_dir + '/domain.yml'))['domain']
         else:
-            host = testinfra.get_host('ansible://icinga-host', ansible_inventory=self.inventory)
+            host = testinfra.get_host('ansible://icinga-host',
+                                      ssh_identity_file=self.ssh_identity_file,
+                                      ansible_inventory=self.inventory)
             return host.ansible.get_variables()['ansible_host']
 
     def get_client(self):
